Try to tidy a model with broom::tidy(). If it fails, will try to tidy the
model using parameters::model_parameters() through tidy_parameters().
tidy_with_broom_or_parameters(x, conf.int = TRUE, conf.level = 0.95, ...)a model
logical indicating whether or not to include a confidence interval in the tidied output
the confidence level to use for the confidence interval
additional parameters passed to broom::tidy() or
parameters::model_parameters()
Other custom_tieders:
tidy_parameters()